## 3rd-party Puppet modules

This repository contains *metadata* for 3rd-party puppet modules in the form of
a `Puppetfile`. The actual 3rd-party code is not included in this repository,
but rather downloaded and deployed when needed with the aid of g10k[1], which
is available in Debian[2].

**IMPORTANT:**

- All modules should be pinned to a Git repository and commit hash, to avoid
  some risks related to MITM. We don't use g10k's sha256sum checking feature
  because it currently does not behave in a nice way[3].

- Dependencies need to be handled manually: when you add or update a module,
  you'll need to manually and recursively include its dependencies in the
  Puppetfile.

- The `modules/` subdirectory is intentionally ignored by Git, so it can be
  populated on the fly when needed using g10k. Please **don't** commit code
  there.

If you want to install the 3rd-party code in the `modules/` directory, run the
following in the root of this repository:

    export g10k_cachedir=$HOME/.cache/g10k
    mkdir -p $g10k_cachedir
    g10k -puppetfile

This will install all modules as listed in the `Puppetfile`.

[1] https://github.com/xorpaul/g10k
[2] https://packages.debian.org/stable/g10k
[3] https://github.com/xorpaul/g10k/issues/231

## Editing eyaml data

Eyaml data is protected with a key that doesn't live in this repository.

Assuming you already have access to the Sysadmins' password-store, you need to
manually put the private and public eyaml keys in the `./keys` directory in
order to be able to edit `*.eyaml` files under `data/`:

```
pass tor/eyaml/puppet.lizard/public_key.pkcs7.pem > keys/public_key.pkcs7.pem
pass tor/eyaml/puppet.lizard/private_key.pkcs7.pem > keys/private_key.pkcs7.pem
```

After that, you should be able to edit `*.eyaml` files using the `eyaml` tool
from the `hiera-eyaml` package:

```
sudo apt-get -f install hiera-eyaml
eyaml edit data/common.eyaml
```

### Eyaml data for masterless nodes

Some nodes (eg. `stone`) run Puppet in a "masterless" setup (see
`tails_profile_puppet::masterless`) and use node-specific keys to protect
their eyaml data. For example:

```
NODE=stone.tails.net
mkdir ./keys/${NODE}
pass tor/eyaml/${NODE}/public_key.pkcs7.pem > keys/${NODE}/public_key.pkcs7.pem
pass tor/eyaml/${NODE}/private_key.pkcs7.pem > keys/${NODE}/private_key.pkcs7.pem
eyaml edit \
	--pkcs7-private-key ./keys/${NODE}/private_key.pkcs7.pem \
	--pkcs7-public-key ./keys/${NODE}/public_key.pkcs7.pem \
	data/node/${NODE}.eyaml
```

## Our Puppet Server only accepts signed commits

The remote of this repository that lives in our Puppet Server only accepts
signed commits from sysadmins.

You can check who are the current sysadmins by peeking into the eyaml Hiera
data:

```
eyaml edit data/common.eyaml
```

Look at users defined under `rbac::roles['sysadmin']` and make sure all those
users have a key id set under `rbac::users[$user]`.

On your side, you need to configure Git to sign commits using your OpenPGP key:

```
git config commit.gpgsign true
git config user.signingkey $YOUR_KEY_ID
```

If all of the above is correctly set, then the remote repository in our Puppet
Server should accept your signed commits.

## Manual operations

This is a list of things that we need to do manually:

- Installation of SSH keys in GitLab for website deployment. See the
  `profile::tails::website` class for details.
