# masterless puppet run
#
# assumes this repo is already cloned in /etc/puppet/code
#
class tails_profile_puppet::masterless {
  ensure_packages(['puppet', 'g10k'])

  include tails_profile_puppet::eyaml

  file { '/etc/puppet/puppet.conf':
    ensure  => file,
    mode    => '0644',
    owner   => 'root',
    group   => 'root',
    content => @(EOT),
      [main]
      include_legacy_facts = true
      | EOT
    require => Package['puppet'],
  }

  file { '/etc/puppet/hiera.yaml':
    ensure => symlink,
    target => '/etc/puppet/code/hiera.yaml',
  }

  file { '/usr/local/sbin/g10k.sh':
    ensure  => file,
    mode    => '0755',
    owner   => 'root',
    group   => 'root',
    content => '#!/bin/sh
export g10k_cachedir=/root/.cache/g10k
mkdir -p $g10k_cachedir
cd /etc/puppet/code
/usr/bin/g10k -puppetfile',
  }

  # lint:ignore:strict_indent
  $_service = @(EOT)
  [Unit]
  Description=Timer for masterless puppet runs

  [Service]
  Type=oneshot
  User=root
  Group=root
  ExecStartPre=-find /var/cache/puppet/reports -type f -ctime +1 -exec rm -f {} \;
  ExecStartPre=-/usr/bin/git -C /etc/puppet/code pull --ff-only --verify-signatures
  ExecStartPre=-/usr/local/sbin/g10k.sh
  ExecStart=/usr/bin/puppet apply --modulepath /etc/puppet/code/modules:/etc/puppet/code/site:/etc/puppet/code/legacy /etc/puppet/code/manifests/%H.pp
  | EOT

  $_timer = @(EOT)
  [Unit]
  Description=Timer for masterless puppet runs

  [Timer]
  OnCalendar=*-*-* *:05,35:00
  Persistent=true
  RandomizedDelaySec=1500

  [Install]
  WantedBy=timers.target
  | EOT
  # lint:endignore

  systemd::timer { 'run-puppet.timer':
    timer_content   => $_timer,
    service_content => $_service,
    active          => true,
    enable          => true,
    require         => File['/usr/local/sbin/g10k.sh'],
  }
}
