#!/bin/sh
#
# This script goes through the list of enabled and disabled Mirrorbits mirrors
# and:
# 
#   - If a mirror is enabled but its TLS certificate is invalid, we disable
#     that mirror.
#
#   - If a mirror is disabled but its TLS certificate is valid, we enable
#     that mirror.

PASS=$(cat /etc/mirrorbits-rpc-password)


list_mirrors() {
        mirror_type=$1
        echo $PASS | mirrorbits -a list -$mirror_type | tail -n +2 | awk '{ print $1 }' | sort | xargs
}

valid_tls_cert() {
        mirror=$1
        faketime -f '+1h' timeout 10s openssl s_client \
                -connect $mirror:443 \
                -servername $mirror \
                -verify_return_error </dev/null >/dev/null 2>&1
}

modify() {
        mirror=$1
        action=$2
        echo $PASS \
                | mirrorbits -a $action $mirror \
                | sed -e 's/^Password: \*\+//'
}

for mirror in $( list_mirrors enabled ); do
        if ! valid_tls_cert $mirror; then
                modify $mirror disable
        fi
done

for mirror in $( list_mirrors disabled ); do
        if valid_tls_cert $mirror; then
                modify $mirror enable
        fi
done
