# @summary
#   Manage dropbear
#
# @example
#   include profile::tails::dropbear
#
# @param config
#   the dropbear configuration
#
class profile::tails::dropbear (
  String $config = 'DROPBEAR_OPTIONS="-p 22 -s -j -k -I 600"',
) {
  $packages = [
    'cryptsetup-bin',
    'cryptsetup-initramfs',
    'dropbear-initramfs',
  ]

  # XXX remove the conditional once all nodes have been upgraded to trixie, and
  # move the package to the list above.
  case $facts['os']['distro']['codename'] {
    'bookworm': {
      $_packages = $packages
    }
    default: {
      $_packages = $packages + ['systemd-cryptsetup']
    }
  }

  ensure_packages($_packages)

  file { '/etc/dropbear/initramfs/dropbear.conf':
    ensure  => file,
    owner   => root,
    group   => root,
    mode    => '0644',
    content => $config,
    require => Package['dropbear-initramfs'],
  }

  file { '/etc/dropbear/initramfs/authorized_keys':
    ensure  => file,
    source  => 'file:///root/.ssh/authorized_keys',
    links   => follow,
    require => Package['dropbear-initramfs'],
  }

  exec { '/usr/sbin/update-initramfs -u':
    subscribe   => [
      File['/etc/dropbear/initramfs/dropbear.conf'],
      File['/etc/dropbear/initramfs/authorized_keys'],
    ],
    refreshonly => true,
  }
}
