# @summary
#   Manage a jenkins worker.
#
# @example
#   include profile::tails::isoworker
#
class profile::tails::jenkins::isoworker () {
# allow FT and helpers to ssh in as user jenkins
  rbac::ssh { 'foundations-team-helpers-to-jenkins':
    user    => 'jenkins',
    role    => 'foundations-team-helpers',
    require => User['jenkins'],
  }
  rbac::ssh { 'foundations-team-members-to-jenkins':
    user    => 'jenkins',
    role    => 'foundations-team-members',
    require => User['jenkins'],
  }

# set our role as fact to be able to access role-based hiera
  profile::tails::facts_d::file { 'role':
    content => {
      role => 'isoworker',
    },
  }

# install the necessary packages
  $packages = [
    'dnsmasq-base',
    'ebtables',
    'faketime',
    'git',
    'jq',
    'libvirt-daemon-system',
    'pigz',
    'python3-gitlab',
    'qemu-system-x86',
    'qemu-utils',
    'rake',
    'sudo',
    'vagrant',
    'vagrant-libvirt',
    'vmdb2',
  ]

  ensure_packages($packages)

  @@sshkeys::create_key { "root@${facts['networking']['fqdn']}":
    keytype => 'rsa',
    length  => 4096,
    tag     => 'tails_ssh_keymaster',
  }

# allow unauthenticated access to the Jenkins web interface
  include profile::tails::jenkins::isoworker::reverse_proxy_exception

# firewall config
  include profile::tails::jenkins::isoworker::firewall_exports
  include profile::tails::jenkins::isoworker::firewall_rules

  include profile::tails::jenkins::isotester
  include profile::tails::jenkins::isobuilder
# For the build_IUKs Jenkins job
  include profile::tails::jenkins::iuk_builder

# For the build_website_* Jenkins jobs
  include profile::tails::website::builder
}
